"""Dashboard module for cocosearch.

Provides terminal and web dashboard interfaces for index observability.
"""

from cocosearch.dashboard.terminal import run_terminal_dashboard

__all__ = ["run_terminal_dashboard"]
